from .report import (
    Analysis, Application, Attachment, Company, Content, CVSSv3,
    CustomMetaData, Finding, OWASP, PCIDSS, Platform, Reference, Regulatory,
    Report, Risk, Tag
)


__all__ = [
    Analysis.__name__,
    Application.__name__,
    Attachment.__name__,
    Company.__name__,
    Content.__name__,
    CVSSv3.__name__,
    CustomMetaData.__name__,
    Finding.__name__,
    OWASP.__name__,
    PCIDSS.__name__,
    Platform.__name__,
    Reference.__name__,
    Regulatory.__name__,
    Report.__name__,
    Risk.__name__,
    Tag.__name__,
]



#! /usr/bin/env python
# -*- coding: utf-8 -*-
#
# vim: fenc=utf-8
# vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
#
#

"""
File name: utils.py
Author: dhilipsiva <dhilipsiva@gmail.com>
Date created: 2017-03-15
"""


class EmptyClass(object):
    """
    Just an empty class with nothing to see
    """
    pass


def dict2obj(d):
    if type(d) == list:
        d = [dict2obj(i) for i in d]
    try:
        d = dict(d)
    except (TypeError, ValueError):
        return d
    obj = EmptyClass()
    for k, v in d.items():
        obj.__dict__[k] = dict2obj(v)
    return obj



from setuptools import setup, find_packages

__VERSION__ = '2.0.2'

setup(
    name='ak-vendor',
    version=__VERSION__,
    description="Some vendor scripts that we use here at Appknox",
    long_description="All the Vendor/helper files the Appknox relies on",
    url='https://github.com/appknox/vendor',
    author='appknox',
    author_email='engineering@appknox.com',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
    ],

    keywords='appknox vendor',
    packages=find_packages(),
    data_files=[
        ('excel', ['ak_vendor/translations/ja/vulnerability.xlsx']),
        ('report', [
            'ak_vendor/report/report_template.html',
        ]),
        ('translations', ['ak_vendor/locale/ja/LC_MESSAGES/django.po']),
    ],
    include_package_data=True,
    entry_points='',
    install_requires=[
        'orm-choices==0.3.0',
        'maya==0.5.0',
        'html2text==2018.1.9',
        'attrs>=18.2.0',
        'cvss>=1.8'
    ],
    zip_safe=False,
    extras_require={
        'dev': [
            'django==2.0.20',
            'weasyprint==0.42.2',
            'bumpversion==0.5.3',
            'twine==1.12.1'
        ],
        'test': [''],
    },
)



import json
from os.path import dirname, abspath
from django import template
from django.conf import settings
from django.template import Template, Context
from django.template.engine import Engine
from django.template.loader import render_to_string
from ak_vendor.report import Report
from django.core.wsgi import get_wsgi_application
settings.configure()
application = get_wsgi_application()

CUR_DIR = dirname(abspath(__file__))
template.Library()

class ReportHTMLExporter:
    def __init__(self, report):
        self.report = report

    def to_html(self):
        tpl = open('{}/report/report_template.html'.format(CUR_DIR)).read()
        template = Template(tpl, engine=Engine(libraries={
            'i18n': 'django.templatetags.i18n'
        }))
        context = Context({
            'report': self.report
        })
        content = template.render(context)
        return content

    def to_html_file(self, path=''):
        with open('{}/output.html'.format(path), 'w') as file:
            tpl = self.to_html()
            file.write(tpl)


data = json.load(open('{}/report_sample1.json'.format(CUR_DIR)))
report_obj = Report.from_json(data)
ReportHTMLExporter(report_obj).to_html_file(CUR_DIR)



from gettext import gettext as _


data = [
  {
      "id": "M1_2016",
      "code": "M1",
      "title": _("Improper Platform Usage"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M2_2016",
      "code": "M2",
      "title": _("Insecure Data Storage"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M3_2016",
      "code": "M3",
      "title": _("Insecure Communication"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M4_2016",
      "code": "M4",
      "title": _("Insecure Authentication"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M5_2016",
      "code": "M5",
      "title": _("Insufficient Cryptography"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M6_2016",
      "code": "M6",
      "title": _("Insecure Authorization"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M7_2016",
      "code": "M7",
      "title": _("Client Code Quality"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M8_2016",
      "code": "M8",
      "title": _("Code Tampering"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M9_2016",
      "code": "M9",
      "title": _("Reverse Engineering"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "M10_2016",
      "code": "M10",
      "title": _("Extraneous Functionality"),
      "year": 2016,
      "active": True,
      "type": "mobile"
  },
  {
      "id": "A1_2013",
      "code": "A1",
      "title": _("Injection"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A2_2013",
      "code": "A2",
      "title": _("Broken Authentication and Session Management"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A3_2013",
      "code": "A3",
      "title": _("Cross Site Scripting"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A4_2013",
      "code": "A4",
      "title": _("Insecure Direct Object References"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A5_2013",
      "code": "A5",
      "title": _("Security Misconfiguration"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A6_2013",
      "code": "A6",
      "title": _("Sensitive Data Exposure"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A7_2013",
      "code": "A7",
      "title": _("Missing Function Level Access Control"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A8_2013",
      "code": "A8",
      "title": _("Cross-Site Request Forgery (CSRF)"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A9_2013",
      "code": "A9",
      "title": _("Using Components with Known Vulnerabilities"),
      "year": 2013,
      "active": True,
      "type": "api"
  },
  {
      "id": "A10_2013",
      "code": "A10",
      "title": _("Unvalidated Redirects and Forwards"),
      "year": 2013,
      "active": True,
      "type": "api"
  }
]
